==> infoblox-netmri-3.7.0.0.tar.gz: infoblox-netmri-3.7.0.0/infoblox_netmri/api/remote/models/if_group_defn_remote.py <==
from ..remote import RemoteModel


class IfGroupDefnRemote(RemoteModel):
    """
    This table list out the entries of Interface Group Definitions.


    |  ``GroupID:`` The internal NetMRI identifier of an interface group.
    |  ``attribute type:`` number

    |  ``GroupName:`` The name of the group in the Interface.
    |  ``attribute type:`` string

    |  ``Criteria:`` The group belongs to defined criteria in an interface group.
    |  ``attribute type:`` string

    |  ``Rank:`` The rank specified for the group in an interface.
    |  ``attribute type:`` number

    |  ``SNMPPolling:`` The SNMP polling state in an interface group definition.
    |  ``attribute type:`` number

    |  ``FlowCollection:`` The level of flow collection in an interface group.
    |  ``attribute type:`` number

    |  ``PerfFrequency:`` The performance frequency level in an interface group.
    |  ``attribute type:`` number

    |  ``Timestamp:`` The date and time this record was collected.
    |  ``attribute type:`` datetime

    |  ``MemberCount:`` The total number of member in an interface group.
    |  ``attribute type:`` number

    |  ``UpdatedAt:`` The date and time this record was last modified.
    |  ``attribute type:`` datetime

    """

    properties = ("GroupID",
                  "GroupName",
                  "Criteria",
                  "Rank",
                  "SNMPPolling",
                  "FlowCollection",
                  "PerfFrequency",
                  "Timestamp",
                  "MemberCount",
                  "UpdatedAt",
                  )

==> infoblox-netmri-3.8.0.0.tar.gz: infoblox-netmri-3.8.0.0/infoblox_netmri/api/remote/models/if_group_defn_remote.py <==
from ..remote import RemoteModel


class IfGroupDefnRemote(RemoteModel):
    """
    This table list out the entries of Interface Group Definitions.


    |  ``GroupID:`` The internal NetMRI identifier of an interface group.
    |  ``attribute type:`` number

    |  ``GroupName:`` The name of the group in the Interface.
    |  ``attribute type:`` string

    |  ``Criteria:`` The group belongs to defined criteria in an interface group.
    |  ``attribute type:`` string

    |  ``Rank:`` The rank specified for the group in an interface.
    |  ``attribute type:`` number

    |  ``SNMPPolling:`` The SNMP polling state in an interface group definition.
    |  ``attribute type:`` number

    |  ``FlowCollection:`` The level of flow collection in an interface group.
    |  ``attribute type:`` number

    |  ``PerfFrequency:`` The performance frequency level in an interface group.
    |  ``attribute type:`` number

    |  ``Timestamp:`` The date and time this record was collected.
    |  ``attribute type:`` datetime

    |  ``MemberCount:`` The total number of members in an interface group.
    |  ``attribute type:`` number

    |  ``UpdatedAt:`` The date and time this record was last modified.
    |  ``attribute type:`` datetime

    """

    properties = ("GroupID",
                  "GroupName",
                  "Criteria",
                  "Rank",
                  "SNMPPolling",
                  "FlowCollection",
                  "PerfFrequency",
                  "Timestamp",
                  "MemberCount",
                  "UpdatedAt",
                  )
